==> libjo_01_19.tar.gz: smarty_dir/templates_c/%%5A^5AC^5AC62717%%index_login.tpl.php <==
<?php /* Smarty version 2.6.20, created on 2009-01-19 14:45:49
         compiled from index_login.tpl */ ?>
<div id="column2_main">
		
		<div id="index">
			<p> 781実習室図書管理システムへようこそ </p>
			
<div id="index_search_login">
		<div id="left_column">
		<span class="small_font"> 本のタイトルを入力してください </span>
<form action="book_search.php" method="GET">
		
		
			<input  type="text" name="name" class="search"  value="" /> <br />
			
	    	<label>
	    	<div class="div_left"><input type="submit" class="submit"  value="検索" /> </div>
	    	<input type="hidden" name="switch" value="on" />
		<input type="hidden" name="pagenumber" value="1" />
		</label>
</form>
		
<form action="book_search.php" method="GET">		
		
		<input type="submit"  value="一覧" /> 
		<input type="hidden" name="switch" value="all" />
		<input type="hidden" name="pagenumber" value="1" />
		<input type="hidden" name="category" value="すべての本">
		</form> </div> 		</div> 		



		<div id="right_column">

		<h3> <?php echo $_SESSION['username']; ?>
さんの借りている本	</h3>
		
		<table border=3px>
		<tr> 
			<th> タイトル </th>	<th>返却期限</th> <th>返却する</th>
		</tr>
		
		<?php unset($this->_sections['i']);
$this->_sections['i']['name'] = 'i';
$this->_sections['i']['loop'] = is_array($_loop=$this->_tpl_vars['book_count']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['i']['show'] = true;
$this->_sections['i']['max'] = $this->_sections['i']['loop'];
$this->_sections['i']['step'] = 1;
$this->_sections['i']['start'] = $this->_sections['i']['step'] > 0 ? 0 : $this->_sections['i']['loop']-1;
if ($this->_sections['i']['show']) {
    $this->_sections['i']['total'] = $this->_sections['i']['loop'];
    if ($this->_sections['i']['total'] == 0)
        $this->_sections['i']['show'] = false;
} else
    $this->_sections['i']['total'] = 0;
if ($this->_sections['i']['show']):

            for ($this->_sections['i']['index'] = $this->_sections['i']['start'], $this->_sections['i']['iteration'] = 1;
                 $this->_sections['i']['iteration'] <= $this->_sections['i']['total'];
                 $this->_sections['i']['index'] += $this->_sections['i']['step'], $this->_sections['i']['iteration']++):
$this->_sections['i']['rownum'] = $this->_sections['i']['iteration'];
$this->_sections['i']['index_prev'] = $this->_sections['i']['index'] - $this->_sections['i']['step'];
$this->_sections['i']['index_next'] = $this->_sections['i']['index'] + $this->_sections['i']['step'];
$this->_sections['i']['first']      = ($this->_sections['i']['iteration'] == 1);
$this->_sections['i']['last']       = ($this->_sections['i']['iteration'] == $this->_sections['i']['total']);
?>
		<form action="return1.php?name=Fast CakePHP" method="GET">
		<tr>
			<td> <a href="book_info.php?name=<?php echo $this->_tpl_vars['book_data'][$this->_sections['i']['index']]['book_name']; ?>
"> <?php echo $this->_tpl_vars['book_data'][$this->_sections['i']['index']]['book_name']; ?>
 </a> </td>		<td><?php echo $this->_tpl_vars['book_data'][$this->_sections['i']['index']]['date']; ?>
</td> 
		
			<td> <input type="submit" value="返却する"> </td>
		</tr>
		</form>
		<?php endfor; endif; ?>
		</table>
		</div> 
	</div>

==> libjo_01_25.tar.gz: smarty_dir/templates_c/%%5A^5AC^5AC62717%%index_login.tpl.php <==
<?php /* Smarty version 2.6.20, created on 2009-01-25 20:48:24
         compiled from index_login.tpl */ ?>
<div id="column2_main">
		
		<div id="index">
			<p> 781実習室図書管理システムへようこそ </p>
			
<div id="index_search_login">
		
		<?php if ($this->_tpl_vars['over_book'] == true): ?>
		<?php echo $_SESSION['username']; ?>
さんの返却期限が切れている本 <br />
		<p>	
		<?php unset($this->_sections['i']);
$this->_sections['i']['name'] = 'i';
$this->_sections['i']['loop'] = is_array($_loop=$this->_tpl_vars['book_count']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['i']['show'] = true;
$this->_sections['i']['max'] = $this->_sections['i']['loop'];
$this->_sections['i']['step'] = 1;
$this->_sections['i']['start'] = $this->_sections['i']['step'] > 0 ? 0 : $this->_sections['i']['loop']-1;
if ($this->_sections['i']['show']) {
    $this->_sections['i']['total'] = $this->_sections['i']['loop'];
    if ($this->_sections['i']['total'] == 0)
        $this->_sections['i']['show'] = false;
} else
    $this->_sections['i']['total'] = 0;
if ($this->_sections['i']['show']):

            for ($this->_sections['i']['index'] = $this->_sections['i']['start'], $this->_sections['i']['iteration'] = 1;
                 $this->_sections['i']['iteration'] <= $this->_sections['i']['total'];
                 $this->_sections['i']['index'] += $this->_sections['i']['step'], $this->_sections['i']['iteration']++):
$this->_sections['i']['rownum'] = $this->_sections['i']['iteration'];
$this->_sections['i']['index_prev'] = $this->_sections['i']['index'] - $this->_sections['i']['step'];
$this->_sections['i']['index_next'] = $this->_sections['i']['index'] + $this->_sections['i']['step'];
$this->_sections['i']['first']      = ($this->_sections['i']['iteration'] == 1);
$this->_sections['i']['last']       = ($this->_sections['i']['iteration'] == $this->_sections['i']['total']);
?>
		<?php if ($this->_tpl_vars['book_data'][$this->_sections['i']['index']]['over'] == 'true'): ?>
		 
			<?php echo $this->_tpl_vars['book_data'][$this->_sections['i']['index']]['book_name']; ?>
 
		 	<?php echo $this->_tpl_vars['book_data'][$this->_sections['i']['index']]['period']; ?>
日過ぎています　
		<br />	
		<?php endif; ?>
		<?php endfor; endif; ?>
		</p>
		<?php endif; ?>
		<div id="left_column">
		<span class="small_font"> 本のタイトルを入力してください </span>
<form action="book_search.php" method="GET">
		
		
			<input  type="text" name="name" class="search"  value="" /> <br />
			
	    	<label>
	    	<div class="div_left"><input type="submit" class="submit"  value="検索" /> </div>
	    	<input type="hidden" name="switch" value="on" />
		<input type="hidden" name="pagenumber" value="1" />
		</label>
</form>
		
<form action="book_search.php" method="GET">		
		
		<input type="submit"  value="一覧" /> 
		<input type="hidden" name="switch" value="all" />
		<input type="hidden" name="pagenumber" value="1" />
		<input type="hidden" name="category" value="すべての本">
		</form> </div> 		</div> 		



		<div id="right_column">

		<h3> <?php echo $_SESSION['username']; ?>
さんの借りている本	</h3>
		
		<table border=3px>
		<tr> 
			<th> タイトル </th>	<th>返却期限</th> <th>返却する</th>
		</tr>
		
		<?php unset($this->_sections['i']);
$this->_sections['i']['name'] = 'i';
$this->_sections['i']['loop'] = is_array($_loop=$this->_tpl_vars['book_count']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['i']['show'] = true;
$this->_sections['i']['max'] = $this->_sections['i']['loop'];
$this->_sections['i']['step'] = 1;
$this->_sections['i']['start'] = $this->_sections['i']['step'] > 0 ? 0 : $this->_sections['i']['loop']-1;
if ($this->_sections['i']['show']) {
    $this->_sections['i']['total'] = $this->_sections['i']['loop'];
    if ($this->_sections['i']['total'] == 0)
        $this->_sections['i']['show'] = false;
} else
    $this->_sections['i']['total'] = 0;
if ($this->_sections['i']['show']):

            for ($this->_sections['i']['index'] = $this->_sections['i']['start'], $this->_sections['i']['iteration'] = 1;
                 $this->_sections['i']['iteration'] <= $this->_sections['i']['total'];
                 $this->_sections['i']['index'] += $this->_sections['i']['step'], $this->_sections['i']['iteration']++):
$this->_sections['i']['rownum'] = $this->_sections['i']['iteration'];
$this->_sections['i']['index_prev'] = $this->_sections['i']['index'] - $this->_sections['i']['step'];
$this->_sections['i']['index_next'] = $this->_sections['i']['index'] + $this->_sections['i']['step'];
$this->_sections['i']['first']      = ($this->_sections['i']['iteration'] == 1);
$this->_sections['i']['last']       = ($this->_sections['i']['iteration'] == $this->_sections['i']['total']);
?>
		<form action="return1.php?name=Fast CakePHP" method="GET">
		<tr>

			<td> <a href="book_info.php?name=<?php echo $this->_tpl_vars['book_data'][$this->_sections['i']['index']]['book_name']; ?>
"> <?php echo $this->_tpl_vars['book_data'][$this->_sections['i']['index']]['book_name']; ?>
 </a> </td>		
			
			<?php if ($this->_tpl_vars['book_data'][$this->_sections['i']['index']]['over'] == 'true'): ?>
			<td style="color:#cc0000">
			<?php else: ?>
			<td>
			<?php endif; ?>
			
			<?php echo $this->_tpl_vars['book_data'][$this->_sections['i']['index']]['date']; ?>
</td> 
		
			<td> <input type="submit" value="返却する"> </td>
		</tr>
		</form>
		<?php endfor; endif; ?>
		</table>
		</div> 
	</div>
